@@ -139,6 +139,9 @@ enzyme_str = "Enzyme: "
 
 
 def edge_attr_dict(x: Edge):
+    #print(x.get_enzyme_id())
+    #print(x.get_fa_param())
+    #print()
     return {
         "enzyme_id": x.get_enzyme_id(full=True),
         "reaction_type": x.get_reaction_type(),
@@ -151,7 +154,7 @@ def edge_attr_dict(x: Edge):
         "l1_type": x.get_l1_type(),
         "l2_type": x.get_l2_type(),
         "set_id": x.get_set_id(),
-        "id_fa_raw": x.get_enzyme_id() + "\nFA: " + x.get_fa_param(),
+        "id_fa_raw": x.get_enzyme_id() + "\nFA: " + str(x.get_fa_param()),
         "id_fa_param": x.get_fa_param(),
         "nl_participants": x.get_nl_participants()
     }
