@@ -272,6 +272,8 @@ def binary_test(data: pd.DataFrame,
                 **kwargs) -> pd.Series:
     methods = {
         "wilcoxon": stats.wilcoxon,
+        "mannwhitneyu": stats.mannwhitneyu,
+        "ranksums": stats.ranksums,
         "ttest": stats.ttest_ind
     }
     if isinstance(method, str):
